@@ -15,21 +15,16 @@ use Apache2::RequestRec ();
 use Apache2::Module ();
 use Apache2::CmdParms ();
 use Apache2::Directive ();
-use Apache2::Log ();
-use Apache2::URI ();
 use Apache2::Const -compile => qw(DECLINED OK
 				  OR_ALL RSRC_CONF
 				  TAKE1 RAW_ARGS NO_ARGS);
 
+use Time::HiRes ();
 use MIME::Base64 ();
-use Crypt::CBC ();
-use Crypt::Blowfish ();
-use Digest::MD5 ();
-use Digest::CRC ();
 
 use Apache2::ClickPath::_parse ();
 
-our $VERSION = '1.10';
+our $VERSION = '1.3';
 our $rcounter=int rand 0x10000;
 
 my @directives=
@@ -92,7 +87,7 @@ name2 regexp2
 </ClickPathFriendlySessions>',
    },
    {
-    name         => '</ClickPathFriendlySessions>',
+    name         => '</ClickFriendlySessions>',
     func         => __PACKAGE__ . '::ClickPathFriendlySessionsEND',
     req_override => Apache2::Const::OR_ALL,
     args_how     => Apache2::Const::NO_ARGS,
@@ -105,44 +100,11 @@ name2 regexp2
     args_how     => Apache2::Const::RAW_ARGS,
     errmsg       => 'ClickPathMachine string',
    },
-   {
-    name         => '<ClickPathMachineTable',
-    func         => __PACKAGE__ . '::ClickPathMachineTable',
-    req_override => Apache2::Const::RSRC_CONF,
-    args_how     => Apache2::Const::RAW_ARGS,
-    errmsg       => '<ClickPathMachineTable>
-ip_ext1|name_ext1 [name1 [ip_int1|name_int1]]
-ip_ext2|name_ext2 [name2 [ip_int1|name_int1]]
-...
-</ClickPathMachineTable>',
-   },
-   {
-    name         => '</ClickPathMachineTable>',
-    func         => __PACKAGE__ . '::ClickPathMachineTableEND',
-    req_override => Apache2::Const::OR_ALL,
-    args_how     => Apache2::Const::NO_ARGS,
-    errmsg       => '</ClickPathMachineTable> without <ClickPathMachineTable>',
-   },
-   {
-    name         => 'ClickPathSecret',
-    func         => __PACKAGE__ . '::ClickPathSecret',
-    req_override => Apache2::Const::RSRC_CONF,
-    args_how     => Apache2::Const::RAW_ARGS,
-    errmsg       => 'ClickPathSecret string',
-   },
-   {
-    name         => 'ClickPathSecretIV',
-    func         => __PACKAGE__ . '::ClickPathSecretIV',
-    req_override => Apache2::Const::RSRC_CONF,
-    args_how     => Apache2::Const::RAW_ARGS,
-    errmsg       => 'ClickPathSecretIV string',
-   },
   );
 Apache2::Module::add(__PACKAGE__, \@directives);
 
 sub ClickPathSessionPrefix {
   my($I, $parms, $arg)=@_;
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
   $I->{"ClickPathSessionPrefix"}=$arg;
 }
 
@@ -150,20 +112,17 @@ sub ClickPathMaxSessionAge {
   my($I, $parms, $arg)=@_;
   die "ERROR: Argument to ClickPathMaxSessionAge must be a number\n"
     unless( $arg=~/^\d+$/ );
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
   $I->{"ClickPathMaxSessionAge"}=$arg;
 }
 
 sub ClickPathUAExceptionsFile {
   my($I, $parms, $arg)=@_;
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
   $I->{"ClickPathUAExceptionsFile"}=$arg;
 }
 
 sub ClickPathUAExceptions {
   my($I, $parms, @args)=@_;
 
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
   $I->{"ClickPathUAExceptions"}
     =Apache2::ClickPath::_parse::UAExceptions( $parms->directive->as_string );
 }
@@ -175,14 +134,12 @@ sub ClickPathUAExceptionsEND {
 
 sub ClickPathFriendlySessionsFile {
   my($I, $parms, $arg)=@_;
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
   $I->{"ClickPathFriendlySessionsFile"}=$arg;
 }
 
 sub ClickPathFriendlySessions {
   my($I, $parms, @args)=@_;
 
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
   @{$I}{"ClickPathFriendlySessionsTable",
 	"ClickPathFriendlySessionsReverse"}
     =Apache2::ClickPath::_parse::FriendlySessions( $parms->directive->as_string );
@@ -198,63 +155,9 @@ sub ClickPathMachine {
   die "ClickPathMachine [name] -- name consist of letters, digits or _\n"
     unless( $arg=~/^\w*$/ );
 
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
   $I->{"ClickPathMachine"}=$arg;
 }
 
-sub ClickPathMachineTable {
-  my($I, $parms, @args)=@_;
-
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
-  @{$I}{"ClickPathMachineTable", "ClickPathMachineReverse"}
-    =Apache2::ClickPath::_parse::MachineTable( $parms->directive->as_string );
-}
-
-sub ClickPathMachineTableEND {
-  my($I, $parms, $arg)=@_;
-  die "ERROR: </ClickPathMachineTable> without <ClickPathMachineTable>\n";
-}
-
-sub postconfig {
-  my($conf_pool, $log_pool, $temp_pool, $s) = @_;
-
-  for( $s=Apache2::ServerUtil->server; $s; $s=$s->next ) {
-    my $cfg=Apache2::Module::get_config( __PACKAGE__, $s );
-    if( $cfg ) {
-      if( exists $cfg->{ClickPathSecret} ) {
-	$cfg->{ClickPathSecretIV}="abcd1234"
-	  unless( length $cfg->{ClickPathSecretIV} );
-      }
-    }
-  }
-
-  return Apache2::Const::OK;
-}
-
-sub setPostConfigHandler {
-  my $h=Apache2::ServerUtil->server->get_handlers('PerlPostConfigHandler')||[];
-  unless( grep $_==\&postconfig, @{$h} ) {
-    Apache2::ServerUtil->server->push_handlers
-	('PerlPostConfigHandler'=>\&postconfig);
-  }
-}
-
-sub ClickPathSecret {
-  my($I, $parms, $arg)=@_;
-
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
-  $I->{"ClickPathSecret"}=Apache2::ClickPath::_parse::Secret( $arg );
-  setPostConfigHandler;
-}
-
-sub ClickPathSecretIV {
-  my($I, $parms, $arg)=@_;
-
-  $I=Apache2::Module::get_config( __PACKAGE__, $parms->server );
-  $I->{"ClickPathSecretIV"}=substr( Digest::MD5::md5( $arg ), 0, 8 );
-  setPostConfigHandler;
-}
-
 sub _get_ua_exc {
   my $cf=shift;
 
@@ -319,7 +222,8 @@ sub _get_friendly_session {
 sub handler {
   my $r=shift;
 
-  my $cf=Apache2::Module::get_config(__PACKAGE__, $r->server);
+  my $cf=Apache2::Module::get_config(__PACKAGE__,
+				    $r->server, $r->per_dir_config);
   my $tag=$cf->{"ClickPathSessionPrefix"}
     or return Apache2::Const::DECLINED;
   $r->pnotes( __PACKAGE__.'::tag'=>$tag );
@@ -353,10 +257,6 @@ sub handler {
 			  $pr->subprocess_env( 'SESSION_START' ) );
       $r->subprocess_env( SESSION_AGE=>
 			  $pr->subprocess_env( 'SESSION_AGE' ) );
-      $r->subprocess_env('ClickPathMachineName'=>
-			  $pr->subprocess_env( 'ClickPathMachineName' ) );
-      my $store=$pr->subprocess_env( 'ClickPathMachineStore' );
-      $r->subprocess_env('ClickPathMachineStore'=>$store) if( length $store );
       $r->subprocess_env( SESSION=>$session );
       $newsession=$pr->pnotes( __PACKAGE__.'::newsession' );
       $r->pnotes( __PACKAGE__.'::newsession'=>$newsession )
@@ -371,7 +271,7 @@ sub handler {
     $ref=~s!^(\w+://[^/]+)/+\Q$tag\E[^/]+!$1!;
     $r->headers_in->{Referer}=$ref;
 
-    $r->parse_uri( 'http://localhost'.$file.(length $r->args ? '?'.$r->args : '') );
+    $r->uri( $file );
     $r->subprocess_env( SESSION=>$session );
     $r->subprocess_env( CGI_SESSION=>'/'.$tag.$session );
 
@@ -383,8 +283,8 @@ sub handler {
     (undef, $rtab)=_get_friendly_session( $cf );
     $rtab={} unless( $rtab );
     if( @l==3 and exists $rtab->{$l[1]} ) {
-      my %h=('**'=>'*', '*!'=>'!', '*.'=>'=', '!'=>"\n", '*x'=>'/', '*y'=>'#');
-      $l[2]=~s/(\*[*!.xy]|!)/$h{$1}/ge;
+      my %h=('**'=>'*', '*!'=>'!', '*.'=>'=', '!'=>"\n");
+      $l[2]=~s/(\*[*!.]|!)/$h{$1}/ge;
       $r->subprocess_env( REMOTE_SESSION=>$l[2] );
       $r->subprocess_env( REMOTE_SESSION_HOST=>$rtab->{$l[1]} );
     } else {
@@ -394,68 +294,20 @@ sub handler {
     # extract session start time
     $l[0]=~tr[@\-][+/];
     @l=split /:/, $l[0], 2;	# $l[0]: IP Addr, $l[1]: session
-    if( exists $cf->{ClickPathMachineReverse} ) {
-      if( exists $cf->{ClickPathMachineReverse}->{$l[0]} ) {
-	$r->subprocess_env('ClickPathMachineName'=>$l[0]);
-	$r->subprocess_env('ClickPathMachineStore'=>
-			   $cf->{"ClickPathMachineReverse"}->{$l[0]}->[1])
-	  if( length $cf->{"ClickPathMachineReverse"}->{$l[0]}->[1] );
-      } else {
-	$r->log->notice( "Caught invalid session: Unknown Machine name '$l[0]'" );
-	$r->subprocess_env( INVALID_SESSION=>$r->subprocess_env( 'SESSION' ) );
-	$r->subprocess_env->unset( 'SESSION' );
-	$r->subprocess_env->unset( 'CGI_SESSION' );
-	$r->subprocess_env->unset( 'REMOTE_SESSION' );
-	$r->subprocess_env->unset( 'REMOTE_SESSION_HOST' );
-	$newsession++;
-	goto NEWSESSION;
-      }
-    }
-
-    my $len4=do {use integer; (length( $l[1] )+3)/4;};
-    $len4*=4;
-    $l[1]=MIME::Base64::decode_base64( $l[1].('='x($len4-length( $l[1] ))) );
-
-    if( exists $cf->{ClickPathSecret} ) {
-      my $crypt=Crypt::CBC->new(
-				-key=>$cf->{ClickPathSecret},
-				-keysize=>length($cf->{ClickPathSecret}),
-				-cipher=>'Crypt::Blowfish',
-				-literal_key=>1,
-				-header=>'none',
-				-iv=>$cf->{ClickPathSecretIV},
-			       );
-      $l[1]=$crypt->decrypt( $l[1] );
-    }
-
-    my $crc;
-    if( length( $l[1] ) ) {
-      $crc=Digest::CRC::crc8( substr( $l[1], 1 ) );
-    } else {
-      $crc=-1;			# invalid value
-    }
-
-    @l=unpack "CNNnN", $l[1];
+    @l=unpack "NNnNn", MIME::Base64::decode_base64( $l[1] );
 
     my $maxage=$cf->{"ClickPathMaxSessionAge"};
-    my $age=$r->request_time-$l[1];
-    if( $crc!=$l[0] or ($maxage>0 and $age>$maxage) or $age<0 ) {
-      if( $crc!=$l[0] ) {
-	$r->log->notice( "Caught invalid session: CRC checksum failed" );
-      } else {
-	$r->subprocess_env( EXPIRED_SESSION=>$r->subprocess_env( 'SESSION' ) );
-      }
+    my $age=$r->request_time-$l[0];
+    if( ($maxage>0 and $age>$maxage) or $age<0 ) {
       $r->subprocess_env->unset( 'SESSION' );
       $r->subprocess_env->unset( 'CGI_SESSION' );
       $r->subprocess_env->unset( 'REMOTE_SESSION' );
       $r->subprocess_env->unset( 'REMOTE_SESSION_HOST' );
-      $r->subprocess_env->unset( 'ClickPathMachineName' );
-      $r->subprocess_env->unset( 'ClickPathMachineStore' );
       $newsession++;
       goto NEWSESSION;
     } else {
-      $r->subprocess_env( SESSION_START=>$l[1] );
-      $r->subprocess_env( SESSION_AGE=>$r->request_time-$l[1] );
+      $r->subprocess_env( SESSION_START=>$l[0] );
+      $r->subprocess_env( SESSION_AGE=>$r->request_time-$l[0] );
     }
     $newsession=0;
   } else {
@@ -504,9 +356,8 @@ sub handler {
 	  $r->subprocess_env( REMOTE_SESSION=>$remote_session );
 	  $r->subprocess_env( REMOTE_SESSION_HOST=>$host );
 
-	  my %h=('*'=>'**', '!'=>'*!', '='=>'*.', "\n"=>'!',
-		 '/'=>'*x', '#'=>'*y');
-	  $remote_session=~s^([*!=\n/#])^$h{$1}^ge;
+	  my %h=('*'=>'**', '!'=>'*!', '='=>'*.', "\n"=>'!');
+	  $remote_session=~s/([*!=\n])/$h{$1}/ge;
 
 	  $ref=$el->[1].','.$remote_session;
 	} else {
@@ -520,46 +371,19 @@ sub handler {
 	$ref='';
       }
 
-      my $session_ip=undef;
+      my $session_ip;
       if( exists $cf->{"ClickPathMachine"} ) {
 	$session_ip=$cf->{"ClickPathMachine"};
       } else {
 	my $serverip=$r->connection->local_addr->ip_get;
-
-	if( exists $cf->{"ClickPathMachineTable"} and
-	    exists $cf->{"ClickPathMachineTable"}->{$serverip} ) {
-	  $session_ip=$cf->{"ClickPathMachineTable"}->{$serverip}->[0];
-	  $r->subprocess_env('ClickPathMachineName'=>
-			     $cf->{"ClickPathMachineTable"}->{$serverip}->[0]);
-	  $r->subprocess_env('ClickPathMachineStore'=>
-			     $cf->{"ClickPathMachineTable"}->{$serverip}->[1])
-	    if( length $cf->{"ClickPathMachineTable"}->{$serverip}->[1] );
-	} else {
-	  $r->server->log->error( "Cannot find myself ($serverip) in ClickPathMachineTable" )
-	    if( exists $cf->{"ClickPathMachineTable"} );
-	  $session_ip=MIME::Base64::encode_base64
-	    ( pack( 'C*', split /\./, $serverip, 4 ), '' );
-	  $session_ip=~s/={0,2}$//;
-	}
+	$session_ip=MIME::Base64::encode_base64
+	  ( pack( 'C*', split /\./, $serverip, 4 ), '' );
+	$session_ip=~s/={0,2}$//;
       }
       my $session=pack( 'NNnN',
 			$r->request_time, $$, $rcounter++,
 			$r->connection->id );
       $rcounter%=2**16;
-
-      $session=pack( 'C', Digest::CRC::crc8( $session ) ).$session;
-
-      if( exists $cf->{ClickPathSecret} ) {
-	my $crypt=Crypt::CBC->new(
-				  -key=>$cf->{ClickPathSecret},
-				  -keysize=>length($cf->{ClickPathSecret}),
-				  -cipher=>'Crypt::Blowfish',
-				  -literal_key=>1,
-				  -header=>'none',
-				  -iv=>$cf->{ClickPathSecretIV},
-				 );
-	$session=$crypt->encrypt( $session );
-      }
       $session=MIME::Base64::encode_base64( $session, '' );
       $session=~s/={0,2}$//;
 
@@ -586,18 +410,12 @@ sub OutputFilter {
   my $host;
   my $sprefix;
   my $context;
-  my ($re0, $re1, $re2, $re3, $re4, $the_request);
+  my ($re, $re1, $re2, $re3, $re4, $the_request);
 
 
   unless ($f->ctx) {
     my $r=$f->r;
 
-    if( $r->main ) {
-      # skip filtering for subrequests
-      $f->remove;
-      return Apache2::Const::DECLINED;
-    }
-
     $sess=$r->subprocess_env('CGI_SESSION');
     unless( defined $sess and length $sess ) {
       $f->remove;
@@ -624,7 +442,7 @@ sub OutputFilter {
 	#print STDERR "the_request(2)=$the_request\n";
       }
 
-      my $re=qr,^(https?://\Q$host\E)?(?!\w+:)(?:/\Q$sprefix\E[^/]+)*(.),i;
+      my $re=qr,^(https?://\Q$host\E)?(?!\w+:)(.),i;
       $r->headers_out->{Location}=~s!$re!$2 eq '/'
                                          ? $1.$sess.$2
                                          : $1.$sess.$the_request.$2
@@ -636,7 +454,7 @@ sub OutputFilter {
                                             !e
 	if( exists $r->err_headers_out->{Location} );
 
-      $re=qr,^(\s*\d+\s*;\s*url\s*=\s*(?:https?://\Q$host\E)?)(?!\w+:)(?:/\Q$sprefix\E[^/]+)*(.),i;
+      $re=qr,^(\s*\d+\s*;\s*url\s*=\s*(?:https?://\Q$host\E)?)(?!\w+:)(.),i;
       $r->headers_out->{Refresh}=~s!$re!$2 eq '/'
                                         ? $1.$sess.$2
                                         : $1.$sess.$the_request.$2
@@ -650,13 +468,13 @@ sub OutputFilter {
     } else {
       $the_request="";
 
-      my $re=qr!^(https?://\Q$host\E)?(?:/\Q$sprefix\E[^/]+)*/!i;
+      my $re=qr!^(https?://\Q$host\E)?/!i;
       $r->headers_out->{Location}=~s!$re!$1$sess/!
 	if( exists $r->headers_out->{Location} );
       $r->err_headers_out->{Location}=~s!$re!$1$sess/!
 	if( exists $r->err_headers_out->{Location} );
 
-      $re=qr!^(\s*\d+\s*;\s*url\s*=\s*(?:https?://\Q$host\E)?)(?:/\Q$sprefix\E[^/]+)*/!i;
+      $re=qr!^(\s*\d+\s*;\s*url\s*=\s*(?:https?://\Q$host\E)?)/!i;
       $r->headers_out->{Refresh}=~s!$re!$1$sess/!
 	if( exists $r->headers_out->{Refresh} );
       $r->err_headers_out->{Refresh}=~s!$re!$1$sess/!
@@ -855,7 +673,7 @@ sub OutputFilter {
   $re2=$context->{re2};
   $re3=$context->{re3};
   $re4=$context->{re4};
-  $re0=$context->{re};
+  $re=$context->{re};
   $the_request=$context->{req};
 
   # now, filter the content
@@ -865,7 +683,7 @@ sub OutputFilter {
 
     # if our buffer ends in a split tag ('<strong' for example)
     # save processing the tag for later
-    if (($context->{extra}) = $buffer =~ m/$re0/) {
+    if (($context->{extra}) = $buffer =~ m/$re/) {
       $buffer = substr($buffer, 0, -length($context->{extra}));
     }
 
@@ -971,12 +789,6 @@ is C</-S:s9NNNd:doBAYNNNiaNQOtNNNNNM/index.html> then assuming
 C<ClickPathSessionPrefix> is set to C<-S:> the session identifier would be
 C<s9NNNd:doBAYNNNiaNQOtNNNNNM>.
 
-Starting with version 1.8 a checksum is included in the session ID. Further,
-some parts of the information contained in the session including the checksum
-can be encrypted. This both makes a valid session ID hard to guess. If an
-invalid session ID is detected an error message is printed to the ErrorLog.
-So, a log watching agent can be set up to catch frequent abuses.
-
 If no session identifier is found a new one is created.
 
 Then the session prefix and identifier are stripped from the current URI.
@@ -1028,28 +840,6 @@ in case a friendly session was caught this variable contains it, see below.
 in case a friendly session was caught this variable contains the host it
 belongs to, see below.
 
-=item B<EXPIRED_SESSION>
-
-if a session has expired and a new one has been created the old session is
-stored here.
-
-=item B<INVALID_SESSION>
-
-when a C<ClickPathMachineTable> is used a check is accomplished to ensure the
-session was created by on of the machines of the cluster. If it was not
-a message is written to the C<ErrorLog>, a new one is created and the invalid
-session is written to this environment variable.
-
-=item B<ClickPathMachineName>
-
-when a C<ClickPathMachineTable> is used this variable contains the name of
-the machine where the session has been created.
-
-=item B<ClickPathMachineStore>
-
-when a C<ClickPathMachineTable> is used this variable contains the address of
-the session store in terms of C<Apache2::ClickPath::Store>.
-
 =back
 
 =head2 The Output Filter
@@ -1123,18 +913,6 @@ A name consists of letters, digits and underscores (_).
 The generated session identifier contains the name in a slightly scrambled
 form to slightly hide your infrastructure.
 
-=item B<ClickPathMachineTable>
-
-this is a container directive like C<< <Location> >> or C<< <Directory> >>.
-It defines a 3-column table specifying the layout of your WEB-server cluster.
-Each line consists of max. 3 fields. The 1st one is the IP address or name
-the server is listening on. Second comes an optional machine name in in terms
-of the C<ClickPathMachine> directive. If it is omitted each machine is
-assigned it's line number within the table as name. This means that each
-machine in a cluster must run with exactly the same table regarding the
-line order. The optional 3rd field specifies the address where the session
-store is accessible (see L<Apache2::ClickPath::Store> for more information.
-
 =item B<ClickPathUAExceptions>
 
 this is a container directive like C<< <Location> >> or C<< <Directory> >>.
@@ -1218,107 +996,6 @@ are the same as for C<ClickPathFriendlySessions>. The file is reread every time
 is has been changed avoiding server restarts after configuration changes at
 the prize of memory consumption.
 
-=item B<ClickPathSecret>
-
-=item B<ClickPathSecretIV>
-
-if you want to run something like a shop with our session identifiers they
-must be unguessable. That means knowing a valid session ID it must be
-difficult to guess another one. With these directives a significant part
-of the session ID is encrypted with Blowfish in the cipher block chaining
-mode thus making the session ID unguessable. C<ClickPathSecret> specifies
-the key, C<ClickPathSecretIV> the initialization vector.
-
-C<ClickPathSecretIV> is a simple string of arbitrary length. The first 8
-bytes of its MD5 digest are used as initialization vector. If omitted the
-string C<abcd1234> is the IV.
-
-C<ClickPathSecret> is given as C<http:>, C<https:>, C<file:> or C<data:> URL.
-Thus the secret can be stored directly as data-URL in the httpd.conf or in a
-separate file on the local disk or on a possibly secured server. To enable
-all modes of accessing the WEB the http(s)-URL syntax is a bit extented.
-Maybe you have already used C<http://user:password@server.tld/...>. Many
-browsers allow this syntax to specify a username and password for HTTP
-authentication. But how about proxies, SSL-authentication etc? Well, add
-another colon (:) after the password and append a semicolon (;) delimited
-list of C<key=value> pairs. The special characters (@:;\) can be quoted
-with a backslash (\). In fact, all characters can be quoted. Thus, C<\a> and
-C<a> produce the same string C<a>.
-
-The following keys are defined:
-
-=over 2
-
-=item B<https_proxy>
-
-=item B<https_proxy_username>
-
-=item B<https_proxy_password>
-
-=item B<https_version>
-
-=item B<https_cert_file>
-
-=item B<https_key_file>
-
-=item B<https_ca_file>
-
-=item B<https_ca_dir>
-
-=item B<https_pkcs12_file>
-
-=item B<https_pkcs12_password>
-
-their meaning is defined in L<Crypt::SSLeay>.
-
-=item B<http_proxy>
-
-=item B<http_proxy_username>
-
-=item B<http_proxy_password>
-
-these are passed to L<LWP::UserAgent>.
-
-Remember a HTTP-proxy is accessed with the GET or POST, ... methods whereas
-a HTTPS-proxy is accessed with CONNECT. Don't mix them, see L<Crypt::SSLeay>.
-
-=back
-
-B<Examples>
-
- ClickPathSecret https://john:a\@b\;c\::https_ca_file=/my/ca.pem@secrethost.tld/bin/secret.pl?host=me
-
-fetches the secret from C<https://secrethost.tdl/bin/secret.pl?host=me>
-using C<john> as username and C<a@b;c:> as password. The server certificate
-of secrethost.tld is verified against the CA certificate found in
-C</my/ca.pem>.
-
- ClickPathSecret https://::https_pkcs12_file=/my/john.p12;https_pkcs12_password=a\@b\;c\:;https_ca_file=/my/ca.pem@secrethost.tld/bin/secret.pl?host=me
-
-fetches the secret again from C<https://secrethost.tdl/bin/secret.pl?host=me>
-using C</my/john.p12> as client certificate with C<a@b;c:> as password.
-The server certificate of secrethost.tld is again verified against the CA
-certificate found in C</my/ca.pem>.
-
- ClickPathSecret data:,password:very%20secret%20password
-
-here a data-URL is used that produces the content
-C<password:very secret password>.
-
-The URL's content is fetched by L<LWP::UserAgent> once at server startup.
-
-Its content defines the secret either in binary form or as string of
-hexadecimal characters or as a password. If it starts with C<binary:> the
-rest of the content is taken as is as the key. If it starts with C<hex:>
-C<pack( 'H*', $arg )> is used to convert it to binary. If it starts with
-C<password:> or with neither of them the MD5 digest of the rest of the
-content is used as secret.
-
-The Blowfish algorithm allows up to 56 bytes as secret. In hex and binary
-mode the starting 56 bytes are used. You can specify more bytes but they
-won't be regarded. In password mode the MD5 algorithm produces
-16 bytes long secret.
-
 =back
 
 =head2 Working with a load balancer
@@ -1355,6 +1032,31 @@ Depending on your content and your users community HTTP proxies can
 serve a significant part of your traffic. With C<Apache2::ClickPath>
 almost all request have to be served by your server.
 
+=head2 Using with SSI
+
+Server Side Includes are also implemented as an output filter. Normally
+Perl output filters are called I<before> mod_include leading to
+unexpected results if an SSI statement generated links. On the other
+hand one can configure the C<INCLUDES> filter with C<PerlSetOutputFilter>
+which preserves the order given in the configuration file.
+Unfortunately there is no C<PerlSetOutputFilterByType> directive and
+and the C<INCLUDES> filter processes everything independend of the
+C<Content-Type>. Thus, also images and other stuff is scanned for
+SSI statements.
+
+With Apache 2.2 there will be a filter dispatcher module that can maybe
+address this problem.
+
+Currently my only solution to this problem is a little module
+C<Apache2::RemoveNextFilterIfNotTextHtml> and setting up the filter
+chain with C<PerlOutputFilterHandler> and C<PerlSetOutputFilter>:
+
+ PerlOutputFilterHandler Apache2::RemoveNextFilterIfNotTextHtml
+ PerlSetOutputFilter INCLUDES
+ PerlOutputFilterHandler Apache2::ClickPath::OutputFilter
+
+Don't hesitate to contact me if you are interested in this little module.
+
 =head2 Debugging
 
 Sometimes it is useful to know the information encoded in a session
@@ -1362,9 +1064,7 @@ identifier. This is why L<Apache2::ClickPath::Decode> exists.
 
 =head1 SEE ALSO
 
-L<Apache2::ClickPath::Store>
-L<Apache2::ClickPath::StoreClient>
-L<Apache2::ClickPath::Decode>
+L<Apache2::ClickPath::Decode(3)>
 L<http://perl.apache.org>,
 L<http://httpd.apache.org>
 
